@@ -290,7 +290,14 @@ def resample(counts, edges, data, rnd, range = (-2.5, 2.5), bins = 100) :
         calibration statistics for each event).
   """
   centres = [ 0.5*(e[:-1]+e[1:]) for e in edges ]
-  interp_func = RegularGridInterpolator(centres, counts, bounds_error = False, fill_value = 0.)
+
+  # Pad each dimension by 1 bin in each dimension, and calculate additional bin centres linearly
+  # Needed to improve interpolation at the edges (when data points are less than half bin size from the boundary)
+  end_values = [ (2.*c[0]-c[1], 2.*c[-1]-c[-2] ) for c in centres ]
+  counts2 = np.pad(counts, [(1,1) for c in centres ], 'edge')
+  centres2 = [ np.pad(c, (1, 1), 'constant', constant_values = e) for c,e in zip(centres, end_values) ]
+  
+  interp_func = RegularGridInterpolator(centres2, counts2, bounds_error = False, fill_value = 0.)
   out = []
   for i in np.linspace(range[0], range[1], bins) : 
     arr = np.concatenate([ i*np.ones_like(data[:,0:1]), data], axis = 1)
