@@ -30,13 +30,13 @@ bck_color  = "xkcd:teal"
 diff_color = "xkcd:red"
 
 @contextmanager
-def plot(name, prefix) : 
+def plot(name, prefix, figsize = (3.5, 2.7)) : 
   """
   Auxiliary function to simplify matplotlib plotting
   (using "with" statement). Opens the subplot and 
   after yielding saves the figs to .pdf and .png files
   """
-  fig, ax = plt.subplots(figsize = (3.5, 2.7) )
+  fig, ax = plt.subplots(figsize = figsize )
   fig.subplots_adjust(bottom=0.18, left = 0.18, right = 0.9, top = 0.9)
   yield fig, ax
   fig.savefig(prefix + name + ".pdf")
@@ -50,6 +50,7 @@ def set_lhcb_style(grid = True, size = 10, usetex = False) :
   """
   plt.rc('font', family='serif', size=size)
   plt.rc('text', usetex = usetex)
+  plt.rcParams['figure.max_open_warning']=40
   plt.rcParams['axes.linewidth']=1.3
   plt.rcParams['axes.grid']=grid
   plt.rcParams['grid.alpha']=0.3
@@ -126,7 +127,7 @@ def plot_hist2d(hist, fig, ax, labels, cmap = "YlOrBr", log = False, symmetric =
   if log : 
     cb.ax.set_yscale("log")
 
-def plot_distr2d(xarr, yarr, bins, ranges, fig, ax, labels, cmap = "YlOrBr", 
+def plot_distr2d(arr, xindex, yindex, bins, ranges, fig, ax, labels, cmap = "YlOrBr", 
                  log = False, ztitle = None, title = None, units = (None, None), 
                  weights = None, colorbar = True) : 
   """
@@ -143,7 +144,18 @@ def plot_distr2d(xarr, yarr, bins, ranges, fig, ax, labels, cmap = "YlOrBr",
   """
   #print(xarr.shape, yarr.shape, bins)
   #print("hist2d start")
-  counts, xedges, yedges = onp.histogram2d(xarr, yarr, bins = bins, range = ranges, weights = weights)
+  counts = None
+  xedges = None
+  yedges = None
+  for a,w in zip(arr, weights) : 
+    c, xe, ye = onp.histogram2d(a[:,xindex], a[:,yindex], bins = bins, range = ranges, weights = w)
+    if counts is None : 
+      counts = c
+      xedges = xe
+      yedges = ye
+    else : 
+      counts += c
+
   #print("hist2d end")
   norm = None
   if log : 
@@ -168,7 +180,7 @@ def plot_distr2d(xarr, yarr, bins, ranges, fig, ax, labels, cmap = "YlOrBr",
     if log : 
       cb.ax.set_yscale("log")
 
-def plot_distr1d(arr, bins, range, ax, label, log = False, units = None, weights = None, title = None, color = None, legend = None) : 
+def plot_distr1d(arr, index, bins, range, ax, label, log = False, units = None, weights = None, title = None, color = None, legend = None) : 
   """
     Plot 1D histogram and its fit result. 
       hist : histogram to be plotted
@@ -178,15 +190,26 @@ def plot_distr1d(arr, bins, range, ax, label, log = False, units = None, weights
       label : x axis label title
       units : Units for x axis
   """
-  if isinstance(weights, list) : 
+  if isinstance(weights, tuple) : 
     xarr = None
     if log : ax.set_yscale("log")
-    for i,w in enumerate(weights) : 
-      hist, edges = onp.histogram(arr, bins = bins, range = range, weights = w)
+    for i,ww in enumerate(weights) : 
+      #hist, edges = onp.histogram(arr, bins = bins, range = range, weights = w)
+
+      counts = None
+      edges = None
+      for a,w in zip(arr,ww) : 
+        c, e = onp.histogram(a[:,index], bins = bins, range = range, weights = w)
+        if counts is None : 
+          counts = c
+          edges = e
+        else : 
+          counts += c
+
       if xarr is None : 
         left,right = edges[:-1],edges[1:]
         xarr = np.array([left,right]).T.flatten()
-      dataarr = np.array([hist,hist]).T.flatten()
+      dataarr = np.array([counts,counts]).T.flatten()
       if color : this_color = color[i]
       else : this_color = f"C{i}"
       if legend : lab = legend[i]
@@ -196,10 +219,21 @@ def plot_distr1d(arr, bins, range, ax, label, log = False, units = None, weights
   else : 
     if color : this_color = color
     else : this_color = data_color
-    hist, edges = onp.histogram(arr, bins = bins, range = range, weights = weights)
+    #hist, edges = onp.histogram(arr, bins = bins, range = range, weights = weights)
+
+    counts = None
+    edges = None
+    for a,w in zip(arr, weights) : 
+      c, e = onp.histogram(a[:,index], bins = bins, range = range, weights = w)
+      if counts is None : 
+        counts = c
+        edges = e
+      else : 
+        counts += c
+
     left,right = edges[:-1],edges[1:]
     xarr = np.array([left,right]).T.flatten()
-    dataarr = np.array([hist,hist]).T.flatten()
+    dataarr = np.array([counts,counts]).T.flatten()
     if log : ax.set_yscale("log")
     ax.plot(xarr, dataarr, color = this_color)
     ax.fill_between( xarr, dataarr, 0., color = this_color, alpha = 0.1)
