@@ -629,7 +629,7 @@ def resample_data(data, config, variable, template, chunk_size = 50000, verbose
   norm_data = de.normalise(data, normaliser[1:], normalise_methods[1:])
 
   if (verbose) : 
-    print(f"Normalised data: {norm_data}")
+    print(f"Normalised data: {norm_data[:100]}")
 
   start_index = 0
   chunk = 0
